@@ -2,8 +2,8 @@
 
 import threading
 
-from masterful_gui.backend.apps.api import policy_search_task_scanner
 from masterful_gui.backend.apps.api import dataset_scanner
+from masterful_gui.backend.apps.api import training_run_scanner
 
 # Interval for periodic scanning.
 _INTERVAL_SEC = 60.0
@@ -29,7 +29,7 @@ def _scan(reschedule: bool) -> None:
     reschedule: Whether to reschedule a scan upon execution.
   """
   try:
-    policy_search_task_scanner.scan()
+    training_run_scanner.scan()
     dataset_scanner.scan()
   except Exception as e:
     print(f'Scanning for serialized protos failed: {str(e)}')
