@@ -5,6 +5,7 @@ from masterful_gui.backend.apps.api import serializers
 from masterful_gui.backend.apps.api import models
 from masterful_gui.backend.apps.api import policy_search_task_scanner
 from masterful_gui.backend.apps.api import dataset_scanner
+from masterful_gui.backend.apps.api import training_run_scanner
 
 
 class PolicySearchTaskView(viewsets.ReadOnlyModelViewSet):
@@ -17,12 +18,17 @@ class DatasetView(viewsets.ReadOnlyModelViewSet):
   queryset = models.Dataset.objects.all()
 
 
+class TrainingRunView(viewsets.ReadOnlyModelViewSet):
+  serializer_class = serializers.TrainingRunModelSerializer
+  queryset = models.TrainingRun.objects.all().order_by('-completed_ts')
+
+
 def scan_view(request):
   """This performs scans on all protos supported by visualize."""
   # TODO: improve the experience. Consider reroute or surfacing
   # a template. This is not required it's just for aesthetics.
   try:
-    policy_search_task_scanner.scan()
+    training_run_scanner.scan()
     dataset_scanner.scan()
   except Exception as e:
     print(str(e))
